@@ -1,5 +1,8 @@
 package Bio::Protease::Types;
-our $VERSION = '1.092550';
+our $VERSION = '1.092560';
+
+
+# ABSTRACT: Specific types for Bio::Protease
 
 use MooseX::Types::Moose qw(Str ArrayRef);
 use MooseX::Types -declare => [qw(ProteaseName ProteaseRegex)];
@@ -27,6 +30,7 @@ sub _str_to_prot_regex {
 
 __PACKAGE__->meta->make_immutable;
 
+
 __END__
 
 =pod
@@ -37,12 +41,27 @@ Bio::Protease::Types - Specific types for Bio::Protease
 
 =head1 VERSION
 
-version 1.092550
+version 1.092560
 
 =head1 DESCRIPTION
 
-This module define specific types and type coercions to be used by
+This module defines specific types and type coercions to be used by
 Bio::Protease. It should not be used by end users, nor is necessary to
 subclass from Bio::ProteaseI.
 
-=cut
\ No newline at end of file
+
+
+=head1 AUTHOR
+
+  Bruno Vecchi <vecchi.b@gmail.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2009 by Bruno Vecchi.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut 
+
+
